@@ -14,6 +14,8 @@ describe 'ovn::controller' do
       :mac_table_size              => 20000,
       :ovn_remote_probe_interval   => 30000,
       :ovn_openflow_probe_interval => 8,
+      :ovn_chassis_mac_map         => ['physnet1:aa:bb:cc:dd:ee:ff',
+                                       'physnet2:bb:aa:cc:dd:ee:ff']
     }
   end
 
@@ -72,6 +74,10 @@ describe 'ovn::controller' do
       is_expected.to contain_vs_config('external_ids:ovn-openflow-probe-interval').with(
         :value   => params[:ovn_openflow_probe_interval],
       )
+
+      is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
+        :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
+      )
     end
 
     it 'configures bridge mappings' do
@@ -89,6 +95,22 @@ describe 'ovn::controller' do
         :require => 'Service[openvswitch]'
       )
     end
+
+    context 'when ovn_chassis_mac_map is a hash' do
+      before :each do
+        params.merge!({
+          :ovn_chassis_mac_map => {
+            'physnet1' => 'aa:bb:cc:dd:ee:ff',
+            'physnet2' => 'bb:aa:cc:dd:ee:ff' }
+        })
+      end
+
+      it 'configures ovsdb' do
+        is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
+          :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
+        )
+      end
+    end
   end
 
   on_supported_os({
